<div align="center">
  <a href="https://github.com/andrewtavis/wiki_rec"><img src="https://github.com/andrewtavis/wikirec/blob/main/resources/wiki_rec_logo.png" width="618" height="200"></a>
</div>

--------------------------------------

### Open-source recommendation engines based on Wikipedia data

**Jump to:** [Data](#data) • [Methods](#methods) • [Examples](#examples) • [To-Do](#to-do)

# Data

# Methods

### LDA

### LDA with BERT embeddings

# Examples

# To-Do

# Similar codes
<details><summary><strong>Similar codes to this project<strong></summary>
<p>

</p>
</details>

# References
<details><summary><strong>List of online references<strong></summary>
<p>

- https://towardsdatascience.com/building-a-recommendation-system-using-neural-network-embeddings-1ef92e5c80c9

- https://towardsdatascience.com/wikipedia-data-science-working-with-the-worlds-largest-encyclopedia-c08efbac5f5c

- https://medium.com/swiftworld/topic-modeling-of-new-york-times-articles-11688837d32f

- https://blog.insightdatascience.com/news4u-recommend-stories-based-on-collaborative-reader-behavior-9b049b6724c4

</p>
</details>